@@ -172,6 +172,16 @@ def not_char(ch: str) -> Parser:
     return fn
 
 
+def if_pred(pred: Callable[[Any], bool], parser: Parser) -> Parser:
+    """Allow parsing of the given parser as long as the result passes some
+    user-defined predicate. Otherwise, fail this parser."""
+    def fn(parse_state):
+        parsing = parser(parse_state)
+        if parsing and pred(parsing.value):
+            return parsing
+        return None
+    return fn
+
 def take_while(match_char_fn: Callable[[str], bool], allow_empty: bool = False) -> Parser:
     """Match while a match function returns True."""
     def fn(parse_state):
